<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/plan?lang_cible=fr_tu
// ** ne pas modifier le fichier **

return [

	// C
	'confirmer_deplacement' => 'Es-tus sûr de vouloir déplacer ces éléments ?',

	// D
	'deplacement_en_echec' => 'Échec d’un déplacement.',
	'deplacement_identifiant_absent' => 'Aucun ',
	'deplacement_reussi' => 'Déplacement réussi.',
	'deplacements_en_echec' => '@nb@ déplacements en échec.',
	'deplacements_reussis' => '@nb@ déplacements réussis.',

	// E
	'erreur_aucun_identifiant' => 'Aucun identifiant d’objet.',
	'erreur_autorisation_insuffisante' => 'Autorisation insuffisante.',
	'erreur_deplacement' => 'Déplacement non effectué.',
	'erreur_deplacement_impossible' => 'Déplacement impossible !',
	'erreur_rubriques_parentes_incorrectes' => 'Rubriques parentes incorrectes.',

	// P
	'plan_titre' => 'Plan du site dans l’espace privé',

	// S
	'suggerer_deplier' => 'Cela peut provenir du déplacement d’un grand groupe : dans ce cas la liste de ses enfants n’est pas chargée. Tu dois déplier le bloc (il se chargera), le replier, puis le redéplacer.',

	// T
	'tous_les_statuts' => 'Tous les statuts',
];
